<?php
namespace Teknisa\CMP\Modules\NecessidadeCompras\Services;

use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use Zeedhi\Framework\DB\StoredProcedure\Param;
use Setforms2\Shared\ORM\DateTime;

class CalculoNecessidadeComprasService {
    
    protected $entityManager;
    protected $newCode;
    protected $environment;
    protected $dataSourceManager;
    protected $fileUploader;
    
    public function __construct($entityManager, $newCode, $environment, $dataSourceManager, $fileUploader) {
        $this->connection = $entityManager->getConnection();
        $this->newCode = $newCode;
        $this->environment = $environment;
        $this->dataSourceManager = $dataSourceManager;
        $this->fileUploader = $fileUploader;
    }
    
    public function completaProd($campo)
    {
        return str_pad($campo, 20, 'Z', STR_PAD_RIGHT);
    }
    
    public function beginTransaction() {
        $this->connection->beginTransaction();
    }
    
    public function commit() {
        $this->connection->commit();
    }
    
    public function rollback() {
        $this->connection->rollback();
    }
    
    public function NECESSIDADE_DE_COMPRAS($cdfilial, $tcdfilial, $groupFili, $datini, $datfin, $prodini, $prodfin, $dtmoment, $acrescimo, $nececomp, $extra, $cdsubgrupo, $cdgrupo) {

        $procedure = new StoredProcedure($this->connection, 'NECESSIDADE_DE_COMPRAS');
        $procedure->addParam(new Param('P_CDFILIAL', Param::PARAM_INPUT, $cdfilial, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_TCDFILIAL', Param::PARAM_INPUT, $tcdfilial, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDGRUPFILI', Param::PARAM_INPUT, $groupFili , Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTINICIAL', Param::PARAM_INPUT, $datini, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTFINAL', Param::PARAM_INPUT, $datfin, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDPRODINI', Param::PARAM_INPUT, $prodini, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDPRODFIN', Param::PARAM_INPUT, $prodfin, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_PEACRESCIMO', Param::PARAM_INPUT, $acrescimo, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDOPERADOR', Param::PARAM_INPUT, $this->environment->getCdoperador(), Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTHRCALCNC', Param::PARAM_INPUT, $dtmoment, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_IDQTDEZERO', Param::PARAM_INPUT, 'S', Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRNECECOMP', Param::PARAM_INPUT, $nececomp, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_EXTRA', Param::PARAM_INPUT, $extra, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDSUBGRUPO', Param::PARAM_INPUT, $cdsubgrupo, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDGRUPPROD', Param::PARAM_INPUT, $cdgrupo, Param::PARAM_TYPE_STR));
        $procedure->execute();
    }
    
    public function CALCULA_PREVCONS_FILIAIS($cdfilial , $tcdfilial, $groupFili, $datfin, $acrescimo, $prodini, $prodfin) {
        $date = new DateTime();
        $date = $date->format('d/m/Y H:i:s');
        
        $procedure = new StoredProcedure($this->connection, 'CALCULA_PREVCONS_FILIAIS');
        $procedure->addParam(new Param('P_CDFILIAL', Param::PARAM_INPUT, $cdfilial, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_TCDFILIAL', Param::PARAM_INPUT, $tcdfilial, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDGRUPFILI', Param::PARAM_INPUT, $groupFili, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTFINAL', Param::PARAM_INPUT, $datfin, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_PEACRESCIMO', Param::PARAM_INPUT, $acrescimo, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDPRODUTOINI', Param::PARAM_INPUT, $prodini, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDPRODUTOFIN', Param::PARAM_INPUT, $prodfin, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDOPERADOR', Param::PARAM_INPUT, $this->environment->getCdoperador(), Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTHRCALCPC', Param::PARAM_INPUT, $date, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_IDARREDOND', Param::PARAM_INPUT, 'N', Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_STDTFINAL', Param::PARAM_INPUT, NULL, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_STDTINICIAL', Param::PARAM_INPUT, NULL, Param::PARAM_TYPE_STR));
        $procedure->execute();
    }
    
    public function PERIODICIDADE_NAO_CALCULADA($cdfilial, $tcdfilial, $groupFili, $prodini, $prodfin) {
        
        $procedure = new StoredProcedure($this->connection, 'PERIODICIDADE_NAO_CALCULADA');
        $procedure->addParam(new Param('P_CDFILIAL', Param::PARAM_INPUT, $cdfilial, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_TCDFILIAL', Param::PARAM_INPUT, $tcdfilial, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDGRUPFILI', Param::PARAM_INPUT, $groupFili, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDPRODINI', Param::PARAM_INPUT, $prodini, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDPRODFIN', Param::PARAM_INPUT, $prodfin, Param::PARAM_TYPE_STR));
        $procedure->execute();
    }
    
    public function GERA_SOLICITACAO($nececomp, $extra, $msg) {
        
        $procedure = new StoredProcedure($this->connection, 'GERA_SOLICITACAO');
        $procedure->addParam(new Param('P_CDFILILANC', Param::PARAM_INPUT, $this->environment->getCdfilial(), Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRNECECOMP', Param::PARAM_INPUT, $nececomp, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDOPERLANC', Param::PARAM_INPUT, $this->environment->getCdoperador(), Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_EXTRA', Param::PARAM_INPUT, $extra, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_MSGEXTRA', Param::PARAM_INPUT, $msg, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_MOBILE', Param::PARAM_INPUT, 'S', Param::PARAM_TYPE_STR));
        $procedure->execute();
    }
    
    public function existeSolicitacaoMerenda($row) {
        
        $params = array();
        $params['P_CDFILIAL']   = $row['CDFILIAL'];
        $params['P_DTINI']      = $row['DTINI'];
        $params['P_DTFIN']      = $row['DTFIM'];
        $params['P_CDPRODINI']  = $row['CDPRODINI'];
        $params['P_CDPRODFIN']  = self::completaProd($row['PRODUTOFIN']);
            
        $sql = "SELECT SOLICITA.CDFILSOLI,
                       SOLICITA.CDFILLANCA,
                       SOLICITA.NRSOLICMP
                  FROM SOLICITA INNER JOIN FILIAL   ON SOLICITA.CDFILSOLI   = FILIAL.CDFILIAL 
                                                   AND SOLICITA.NRORG       = FILIAL.NRORG
                                INNER JOIN ITEMSOLI ON SOLICITA.CDFILSOLI   = ITEMSOLI.CDFILSOLI
                                                   AND SOLICITA.CDFILLANCA  = ITEMSOLI.CDFILLAN
                                                   AND SOLICITA.NRSOLICMP   = ITEMSOLI.NRSOLICMP
                                                   AND SOLICITA.NRORG       = ITEMSOLI.NRORG
                                INNER JOIN PRODUTO  ON ITEMSOLI.CDPRODUTO   = PRODUTO.CDPRODUTO
                                                   AND ITEMSOLI.NRORG       = PRODUTO.NRORG
                 WHERE FILIAL.CDFILIAL   = :P_CDFILIAL
                   AND SOLICITA.IDTIPLAN = 'A'
                   AND ITEMSOLI.DTPROGENTR BETWEEN :P_DTINI AND :P_DTFIN
                   AND PRODUTO.CDARVPROD BETWEEN :P_CDPRODINI AND :P_CDPRODFIN";
        
        $stmt = $this->connection->prepare($sql);
        $stmt->execute($params);
        return $stmt->fetchAll();    
    }
    
    public function adqConfereNeceComp($nececomp, $dtinicial){
        $params = array(
    		"P_NRNECECOMP" => $nececomp,
    		"P_DTINICIAL" => $dtinicial,
    		"NRORG" => $this->environment->getNrorg()
    	);

    	$sql = "SELECT TRABNECECOMP.CDFILNECECMP, FILIAL.NMFILIAL, TRABNECECOMP.NRNECECOMP
    	          FROM FILIAL INNER JOIN TRABNECECOMP ON TRABNECECOMP.CDFILNECECMP = FILIAL.CDFILIAL
    	                                             AND TRABNECECOMP.NRORG        = FILIAL.NRORG
    	         WHERE TRABNECECOMP.NRNECECOMP = :P_NRNECECOMP
    	           AND TRABNECECOMP.NRORG = :NRORG
    	           AND TRABNECECOMP.DTENTRNECCMP >= TO_DATE(:P_DTINICIAL, 'DD/MM/YYYY')
    	           AND QTPRACOMPRAR > 0
    	         GROUP BY TRABNECECOMP.CDFILNECECMP, FILIAL.NMFILIAL, TRABNECECOMP.NRNECECOMP";
    	
    	$stmt = $this->connection->prepare($sql);
        $stmt->execute($params);
        return $stmt->fetchAll(); 
    }
    
    public function selectCentral(){
        $params = array(
    		"P_CDFILIAL" => $this->environment->getCdfilial(),
    		"NRORG" => $this->environment->getNrorg()
    	);
    	$sql = "SELECT NVL(FILIAL.CDFILCENTCMP, FILIAL.CDFILIAL) AS CENTRALCMP, 
                       FIL.NMFILIAL AS NMFILIAL_CENTRAL
                  FROM FILIAL FIL INNER JOIN FILIAL ON NVL(FILIAL.CDFILCENTCMP, FILIAL.CDFILIAL) = FIL.CDFILIAL
                                                   AND FILIAL.NRORG                              = FIL.NRORG        
                 WHERE FILIAL.CDFILIAL = :P_CDFILIAL
                   AND FILIAL.NRORG = :NRORG";
    	
    	$query = $this->connection->prepare($sql);
    	$query->execute($params);
    	$central = $query->fetchAll();
    	if (!empty($central[0]['CENTRALCMP'])) {
    	    return $central[0]['CENTRALCMP'];
    	}
    }
    
    public function selectGrupo($central){
        $params = array(
    		"P_CENTRALCMP" => $central,
    		"NRORG" => $this->environment->getNrorg()
    	);
    	
    	$sql = "SELECT CDGRUPPROD 
    	          FROM PARASUPRI
    	         WHERE CDFILIAL = :P_CENTRALCMP
    	           AND NRORG = :NRORG";
    	
    	$query = $this->connection->prepare($sql);
    	$query->execute($params);
    	$subgrupo = $query->fetchAll();
    	if (!empty($subgrupo[0]['CDGRUPPROD'])) {
    	    return $subgrupo[0]['CDGRUPPROD'];
    	}

    }

    public function selectCardapio(){
        $params = array(
    		"NRORG" => $this->environment->getNrorg()
    	);
    	
    	$sql = "SELECT IDSISDOS, IDUTCARDPADR
    	          FROM PARAMGERAL
    	         WHERE NRORG = :NRORG";
    	$query = $this->connection->prepare($sql);
    	$query->execute($params);
    	$calen = $query->fetchAll();
        if (!empty($calen[0])) {
    	    return $calen[0];
    	} 
    }
    
    public function selectDados(){
        $params = array(
    		"P_CDFILIAL" => $this->environment->getCdfilial(),
    		"NRORG" => $this->environment->getNrorg()
    	);
    	$sql = "SELECT IDCALPREVCON, IDPERACRNEC, IDPERCESTNEC, IDSCONESTNEC
    	          FROM PARCMPSUP
    	         WHERE CDFILIAL = :P_CDFILIAL
    	           AND NRORG = :NRORG";
    	$query = $this->connection->prepare($sql);
    	$query->execute($params);
    	$dados = $query->fetchAll();
        if (!empty($dados[0])) {
    	    return $dados[0];
    	}    
    }
    
    public function selectEstoque($row) {
        $params = array(
    		"P_CDFILIAL" => $row['CDFILIAL'],
    		"NRORG" => $this->environment->getNrorg()
    	);
    	$sql = "SELECT IDCALPREVCON, IDPERACRNEC, IDPERCESTNEC, IDSCONESTNEC
    	          FROM PARCMPSUP
    	         WHERE CDFILIAL = :P_CDFILIAL
    	           AND NRORG = :NRORG";
    	$query = $this->connection->prepare($sql);
    	$query->execute($params);
    	return $query->fetchAll();
    }
    
    public function selectGetLimiSegu($cdfilial, $cdprodini, $cdprodfin, $groupfili){
        $params = array(
    		"P_CDGRUPFILI" => $groupfili,
    		"P_CDFILIAL" => $cdfilial,
    		"P_CDPRODUTOINI" => $cdprodini,
    		"P_CDPRODUTOFIN" => $cdprodfin = self::completaProd($cdprodfin),
    		"NRORG" => $this->environment->getNrorg()
    	);

    	$sql = "SELECT MAX(NRLIMISEGU) AS MAXLIMISEG
    	          FROM ( SELECT CDFILIAL, NRORG
    	                   FROM FILGRUPFILI
    	                  WHERE FILGRUPFILI.CDGRUPFILI = :P_CDGRUPFILI
    	                    AND NRORG = :NRORG
    	                    AND (INSTR(:P_CDFILIAL, FILGRUPFILI.CDFILIAL) > 0 OR :P_CDFILIAL = 'T')
    	                  UNION
    	                 SELECT CDFILIAL, NRORG
    	                   FROM FILIAL
    	                  WHERE :P_CDGRUPFILI IS NULL
    	                    AND NRORG = :NRORG
    	                    AND (INSTR(:P_CDFILIAL, FILIAL.CDFILIAL) > 0 OR :P_CDFILIAL = 'T')) FILGRUPFILI, 
    	               LIMISEGPROD, 
    	               ( SELECT CDPRODUTO, NRORG
    	                   FROM PRODUTO
    	                  WHERE PRODUTO.CDARVPROD BETWEEN :P_CDPRODUTOINI AND :P_CDPRODUTOFIN
    	                    AND NRORG = :NRORG
    	                  UNION
    	                 SELECT CDPRODUTO, NRORG
    	                   FROM PRODUTO
    	                  WHERE :P_CDPRODUTOINI LIKE PRODUTO.CDARVPROD ||'%'
    	                    AND NRORG = :NRORG) PRODUTO
    	         WHERE LIMISEGPROD.CDPRODUTO = PRODUTO.CDPRODUTO
    	           AND LIMISEGPROD.NRORG = PRODUTO.NRORG
    	           AND FILGRUPFILI.CDFILIAL = LIMISEGPROD.CDFILIAL
    	           AND FILGRUPFILI.NRORG = LIMISEGPROD.NRORG";
    	$query = $this->connection->prepare($sql);
    	$query->execute($params);
    	$limi = $query->fetchAll();
    	
    	if (!empty($limi[0])) {
    	    return $limi[0];
    	}
    }
    
    public function calculaDataLimiteSeguranca($cdfilial, $cdprodini, $cdprodfin, $groupfili, $data) {
        
        $limi = $this->selectGetLimiSegu($cdfilial, $cdprodini, $cdprodfin, $groupfili);
  
        $data = str_replace("/", "-", $data);
        $data = new DateTime($data);
        $data->add(new \DateInterval('P01M'));
        $diaSeguranca = $limi['MAXLIMISEG'] ? $limi['MAXLIMISEG'] : 0;
        $data->add(new \DateInterval('P' . $diaSeguranca . 'D'));
        
        return $data;
    }
    
    public function selectGetServNAprov($datini, $datfin, $cdfilial, $groupFili){
        $params = array(
    		"P_CDGRUPFILI" => $groupFili,
    		"P_CDFILIAL" => $cdfilial,
    		"P_DTMESINI" => $datini,
    		"P_DTMESFIM" => $datfin,
    		"NRORG" => $this->environment->getNrorg()
    	);

    	$sql = "SELECT SE.CDFILIAL, SE.CDSERVFILI, TO_CHAR(DTMESCALENCARD, 'MM/YYYY') AS DTMESCALENCARD, SE.NRORG FROM SERVICO SE, CALENCARD CL, FILGRUPFILI GP, PARAMPLANEJA PP WHERE (INSTR(:P_CDFILIAL, GP.CDFILIAL)<> 0 or (:P_CDFILIAL = 'T')) AND GP.CDFILIAL = CL.CDFILIAL AND SE.CDFILIAL = CL.CDFILIAL AND GP.CDFILIAL = PP.CDFILIAL AND CL.DTMESCALENCARD BETWEEN TO_DATE(:P_DTMESINI, 'DD/MM/YYYY') AND TO_DATE(:P_DTMESFIM, 'DD/MM/YYYY') AND SE.IDSERVATIV = 'S' AND SE.IDCARDDESCENTR = 'S' AND PP.IDBLOQNECCOMP = 'S' AND (GP.CDGRUPFILI = :P_CDGRUPFILI) AND SE.NRORG = :NRORG AND SE.NRORG = CL.NRORG AND SE.NRORG = GP.NRORG AND SE.NRORG = PP.NRORG AND EXISTS (SELECT CTRL.CDSERVFILI FROM CTRLAPROVCARD CTRL WHERE CTRL.CDFILIAL = SE.CDFILIAL AND CTRL.CDSERVFILI = SE.CDSERVFILI AND CTRL.DTMESCARDAPROV = CL.DTMESCALENCARD AND CTRL.NRORG = SE.NRORG AND CTRL.DTAPROCARDMATR IS NULL) UNION ALL SELECT SE.CDFILIAL, SE.CDSERVFILI, TO_CHAR(DTMESCALENCARD, 'MM/YYYY') AS DTMESCALENCARD, SE.NRORG FROM SERVICO SE, CALENCARD CL, PARAMPLANEJA PP WHERE (INSTR(:P_CDFILIAL, SE.CDFILIAL)<> 0 or (:P_CDFILIAL = 'T')) AND SE.CDFILIAL = CL.CDFILIAL AND SE.CDFILIAL = PP.CDFILIAL AND CL.DTMESCALENCARD BETWEEN TO_DATE(:P_DTMESINI, 'DD/MM/YYYY') AND TO_DATE(:P_DTMESFIM, 'DD/MM/YYYY') AND SE.IDSERVATIV = 'S' AND SE.IDCARDDESCENTR = 'S' AND PP.IDBLOQNECCOMP = 'S' AND :P_CDGRUPFILI IS NULL AND SE.NRORG = :NRORG AND SE.NRORG = CL.NRORG AND SE.NRORG = PP.NRORG AND EXISTS(SELECT CTRL.CDSERVFILI FROM CTRLAPROVCARD CTRL WHERE CTRL.CDFILIAL = SE.CDFILIAL AND CTRL.CDSERVFILI = SE.CDSERVFILI AND CTRL.DTMESCARDAPROV = CL.DTMESCALENCARD AND CTRL.NRORG = SE.NRORG AND CTRL.DTAPROCARDMATR IS NULL)";
    	$query = $this->connection->prepare($sql);
    	$query->execute($params);
    	return $query->fetchAll();
    }
    
    public function selectVerifica_Sol($datini, $datfin, $cdfilial, $groupFili, $prodini, $prodfin, $cdsubgrupo, $grupprod){
        $params = array(
    		"P_CDGRUPFILI" => $groupFili,
    		"P_CDFILIAL" => $cdfilial,
    		"P_CDPRODUTOINI" => $prodini,
    		"P_CDPRODUTOFIN" => $prodfin,
    		"P_DTINI" => $datini,
    		"P_DTFIN" => $datfin,
    		"P_SUBGRUPO" => $cdsubgrupo,
    		"P_CDGRUPPROD" => $grupprod,
    		"NRORG" => $this->environment->getNrorg()
    	);

    	$sql = "SELECT SOLICITA.CDFILSOLI, SOLICITA.CDFILLANCA, SOLICITA.NRSOLICMP, LOGNECECOMP.CDPRODINICNC, PRODINI.NMPRODUTO AS NMPRODINI, LOGNECECOMP.CDPRODFINANC, PRODFIN.NMPRODUTO AS NMPRODFIN, SOLICITA.NRORG FROM PRODUTO PRODINI, PRODUTO PRODFIN, LOGNECECOMP, SOLICITA, (SELECT CDFILIAL, NRORG FROM FILGRUPFILI WHERE (FILGRUPFILI.CDGRUPFILI = :P_CDGRUPFILI) AND (FILGRUPFILI.NRORG = :NRORG) AND (INSTR(:P_CDFILIAL, FILGRUPFILI.CDFILIAL) > 0 OR :P_CDFILIAL = 'T') UNION SELECT CDFILIAL, NRORG FROM FILIAL WHERE (:P_CDGRUPFILI IS NULL) AND (FILIAL.NRORG = :NRORG) AND (INSTR(:P_CDFILIAL, FILIAL.CDFILIAL) > 0 OR :P_CDFILIAL = 'T')) FILGRUPFILI WHERE SOLICITA.IDTIPLAN = 'A' AND SOLICITA.CDFILSOLI = FILGRUPFILI.CDFILIAL AND LOGNECECOMP.NRNECECMPLOG = SOLICITA.NRNECECMPSOL AND LOGNECECOMP.DTINICIALNC = TO_DATE(:P_DTINI, 'DD/MM/YYYY') AND LOGNECECOMP.DTFINALNC = TO_DATE(:P_DTFIN, 'DD/MM/YYYY') AND LOGNECECOMP.CDFILIAL = SOLICITA.CDFILSOLI AND LOGNECECOMP.CDPRODINICNC <= :P_CDPRODUTOFIN AND RPAD(LOGNECECOMP.CDPRODFINANC, 20, 'Z') >= :P_CDPRODUTOINI AND LOGNECECOMP.CDPRODINICNC = PRODINI.CDARVPROD AND LOGNECECOMP.CDPRODFINANC = PRODFIN.CDARVPROD AND SOLICITA.NRORG = LOGNECECOMP.NRORG AND SOLICITA.NRORG = PRODINI.NRORG AND SOLICITA.NRORG = PRODFIN.NRORG AND SOLICITA.NRORG = FILGRUPFILI.NRORG AND ((:P_SUBGRUPO = 'T') OR (EXISTS(SELECT 1 FROM PRSUBGRPROD, PRODUTO WHERE PRSUBGRPROD.CDGRUPPROD = :P_CDGRUPPROD AND PRSUBGRPROD.CDPRODUTO = PRODUTO.CDPRODUTO AND PRSUBGRPROD.NRORG = :NRORG AND PRSUBGRPROD.NRORG = PRODUTO.NRORG AND PRODUTO.CDARVPROD BETWEEN LOGNECECOMP.CDPRODINICNC AND RPAD(LOGNECECOMP.CDPRODFINANC, 20, 'Z') AND ((INSTR(:P_SUBGRUPO, PRSUBGRPROD.CDSUBGRPROD) > 0) OR (:P_SUBGRUPO = 'T')))))";
    	$query = $this->connection->prepare($sql);
    	$query->execute($params);
    	return $query->fetchAll();
    }
    
    public function adqParamServico($cdfilial, $groupFili){
        $params = array(
    		"P_CDGRUPFILI" => $groupFili,
    		"P_CDFILIAL" => $cdfilial,
    	);

    	$sql = "SELECT PARAMPLANEJA.CDFILIAL FROM SERVICO, PARAMPLANEJA, (SELECT FILIAL.CDFILIAL FROM FILIAL WHERE (INSTR(:P_CDFILIAL, FILIAL.CDFILIAL) > 0 OR :P_CDFILIAL = 'T') AND (:P_CDGRUPFILI IS NULL) UNION SELECT FILGRUPFILI.CDFILIAL FROM FILGRUPFILI WHERE (INSTR(:P_CDFILIAL, FILGRUPFILI.CDFILIAL) > 0 OR :P_CDFILIAL = 'T') AND (FILGRUPFILI.CDGRUPFILI = :P_CDGRUPFILI)) FILIAL WHERE (SERVICO.CDFILIAL = FILIAL.CDFILIAL) AND (NVL(SERVICO.IDUTRETIPRAT, 'N') = 'S') AND (PARAMPLANEJA.CDFILIAL = SERVICO.CDFILIAL) AND (NVL(PARAMPLANEJA.IDUTREQUPRAT, 'N') = 'N') AND (CDTPRCONSFIX IS NULL OR CDPRACONSFIX IS NULL OR CDTPRCONSPER IS NULL OR CDPRACONSPER IS NULL) UNION SELECT PARAMPLANEJA.CDFILIAL FROM PARAMPLANEJA, (SELECT FILIAL.CDFILIAL FROM FILIAL WHERE (INSTR(:P_CDFILIAL, FILIAL.CDFILIAL) > 0 OR :P_CDFILIAL = 'T') AND (:P_CDGRUPFILI IS NULL) UNION SELECT FILGRUPFILI.CDFILIAL FROM FILGRUPFILI WHERE (INSTR(:P_CDFILIAL, FILGRUPFILI.CDFILIAL) > 0 OR :P_CDFILIAL = 'T') AND (FILGRUPFILI.CDGRUPFILI = :P_CDGRUPFILI)) FILIAL WHERE (PARAMPLANEJA.CDFILIAL = FILIAL.CDFILIAL) AND (NVL(IDUTREQUPRAT, 'N') = 'S') AND (CDTPRCONSFIX IS NULL OR CDPRACONSFIX IS NULL OR CDTPRCONSPER IS NULL OR CDPRACONSPER IS NULL)";
    	$query = $this->connection->prepare($sql);
    	$query->execute($params);
    	return $query->fetchAll();
    }
    
    public function adqFilialBkg($cdfilial, $groupFili){
        $params = array(
    		"P_CDGRUPFILI" => $groupFili,
    		"P_CDFILIAL" => $cdfilial
    	);

    	$sql = "SELECT FILGRUPFILI.CDFILIAL AS CDFILNECECMP, FILIAL.NMFILIAL FROM FILIAL, FILGRUPFILI WHERE (FILGRUPFILI.CDGRUPFILI = :P_CDGRUPFILI) AND (FILIAL.CDFILIAL = FILGRUPFILI.CDFILIAL) AND (INSTR(:P_CDFILIAL, FILGRUPFILI.CDFILIAL) > 0 OR :P_CDFILIAL = 'T') UNION SELECT CDFILIAL AS CDFILNECECMP, NMFILIAL FROM FILIAL WHERE (:P_CDGRUPFILI IS NULL) AND (INSTR(:P_CDFILIAL, FILIAL.CDFILIAL) > 0 OR :P_CDFILIAL = 'T') ORDER BY CDFILNECECMP";
    	$query = $this->connection->prepare($sql);
    	$query->execute($params);
    	return $query->fetchAll();
    }
    
    public function acmUpdLogNeceComp($cdfilial, $groupFili, $dtmoment, $idcalprevcon, $nececomp, $cdsubgrupo){
        $params = array(
    		"P_CDFILGRUPFILI" => $groupFili,
    		"P_LISTASUBGRPROD" => $cdsubgrupo,
    		"P_IDCALPREVCON" =>  $idcalprevcon,
    		"OLD_CDOPERADOR" => $this->environment->getCdoperador(),
    		"OLD_DTHRCALCNC" => $dtmoment,
    		"OLD_NRNECECMPLOG" => $nececomp,
    		"OLD_CDFILIAL" => $cdfilial
    	);
    	$sql = "UPDATE LOGNECECOMP
            SET CDFILGRUPFILI                   = :P_CDFILGRUPFILI,
              LISTASUBGRPROD                    = :P_LISTASUBGRPROD,
              IDCALPREVCON                      = :P_IDCALPREVCON
            WHERE CDOPERADOR                    = :OLD_CDOPERADOR
            AND TRUNC(DTHRCALCNC)               = :OLD_DTHRCALCNC
            AND NRNECECMPLOG                    = :OLD_NRNECECMPLOG
            AND (INSTR(:OLD_CDFILIAL, CDFILIAL) > 0 OR :OLD_CDFILIAL = 'T')";
        $stmt = $this->connection->prepare($sql);
        $stmt->execute($params);
    }
    
    public function adqProdInativo($nececomp){      
        $params = array(
    		"P_NRNECECOMP" => $nececomp
    	);

    	$sql = "SELECT NRNECCMPINAT, CDFILNECINAT, NMFILIAL, CDARVPROD, NMPRODUTO FROM PRODUTO, FILIAL, TRABNECEINAT WHERE FILIAL.CDFILIAL = TRABNECEINAT.CDFILNECINAT AND PRODUTO.CDPRODUTO = TRABNECEINAT.CDPRONECINAT AND TRABNECEINAT.NRNECCMPINAT = :P_NRNECECOMP ORDER BY NRNECCMPINAT, CDFILNECINAT, CDARVPROD";
    	$query = $this->connection->prepare($sql);
    	$query->execute($params);
    	return $query->fetchAll();
    }
    
    public function retornaEmailOperador($listaOperador) {
        $listaOperador = is_array($listaOperador) ? implode('_', $listaOperador) : $listaOperador;
        
        $params = array(
    		"CDOPERADOR" => $listaOperador,
    		"NRORG" => $this->environment->getNrorg()
    	);

    	$sql = "SELECT DISTINCT DSEMAILOPER
                  FROM OPERADOR
                 WHERE (INSTR(:CDOPERADOR, CDOPERADOR) <> 0)
                   AND NRORG = :NRORG
                   AND DSEMAILOPER IS NOT NULL";
    	
    	$query = $this->connection->prepare($sql);
    	$query->execute($params);
    	
    	return $query->fetchAll();
    }
    
    public function retornaListaEmailOperador($listaOperador) {
        $listaEmails = $this->retornaEmailOperador($listaOperador);
        
        $listaEmails = array_map(function($email) {
            return $email['DSEMAILOPER'];
        }, $listaEmails);
        
        return $listaEmails;
    }
    
    public function selectSolicita($nececomp){
        $params = array(
    		"P_NRNECECMPSOL" => $nececomp
    	);

    	$sql = "SELECT MAX(NRSOLICMP) NRSOLICMP FROM SOLICITA WHERE NRNECECMPSOL = :P_NRNECECMPSOL";
    	$query = $this->connection->prepare($sql);
    	$query->execute($params);
    	return $query->fetchAll();
    }
    
    public function getDataProcessamentoFilial() {
        $query = "SELECT DTPROCESSA, DTPROCESSA + 1 AS DTPROCESSAFUT FROM (SELECT (
                      CASE PARAMGERAL.IDUTILDTPROC
                        WHEN 'N'
                        THEN SYSDATE
                        ELSE NVL(PARAMFILIAL.DTPROCESSA, SYSDATE)
                      END) DTPROCESSA
                    FROM PARAMGERAL,
                      PARAMFILIAL
                    WHERE PARAMFILIAL.CDFILIAL = :P_CDFILIAL)";
                 
        $std = $this->connection->prepare($query);
        $std->execute(
            [
                'P_CDFILIAL' => $this->environment->getCdFilial(),
            ]
        );
        
        return $std->fetchAll();
    }
    
    private function executaSql($sql, $params, $consulta = true) {
        try{
            $std = $this->connection->prepare($sql);
            $std->execute($params);
            
            if($consulta == true) {
                return $std->fetchAll();
            }
            
            return true;
        } catch (\Exception $e){
            throw $e;
        } 
    }
    
    public function deleteEntrega($row)
    {
        $query = "DELETE FROM TRABNECECOMP
                   WHERE NRNECECOMP   = :OLD_NRNECECOMP 
                     AND DTENTRNECCMP = :OLD_DTENTRNECCMP
                     AND CDPRODNECCMP = :OLD_CDPRODNECCMP 
                     AND CDFILNECECMP = :OLD_CDFILNECECMP
                     AND NRORG        = :NRORG";
        
        $params = [
            "OLD_NRNECECOMP"   => $row['NRNECECOMP'],
            "OLD_DTENTRNECCMP" => DateTime::createFromFormat("d/m/Y", substr($row["DTENTRNECCMP"], 0, 10))->format("d/m/Y"),
            "OLD_CDPRODNECCMP" => $row['CDPRODUTO'],
            "OLD_CDFILNECECMP" => $row['CDFILNECECMP'],
            "NRORG"            => $this->environment->getNrOrg()
        ];
        
        return self::executaSql($query, $params, false);
    }
    
    public function getPrevCons($filial, $params)
    {
        $query = "SELECT RPAD(' ', 4, ' ')  CDFILIAL,
                         RPAD(' ', 20, ' ')  NMFILIAL,
                         PT.CDARVPROD,
                         PT.NMPRODUTO,
                         PT.SGUNIDADE,
                         TO_CHAR(PC.DTPREVCONS, 'DD/MM/YYYY') AS DTPREVCONS,
                         SUM(PC.QTPREVCONS) AS QTPREVCONS,
                         RPAD(' ', 10, ' ')   NRNECECMPSOL
                    FROM PRODUTO PT INNER JOIN V_PREVISAO_COMPRA PC ON PT.CDPRODUTO = PC.CDPRODUTO
                   WHERE PC.CDFILIAL = :P_CDFILIAL
                     AND PT.NRORG    = :NRORG
                     AND PC.DTPREVCONS BETWEEN :P_DTINICIAL AND :P_DTFINAL
                     AND PT.CDARVPROD  BETWEEN :P_CDPRODINI AND :P_CDPRODFIN
                   GROUP BY PT.CDARVPROD, PC.DTPREVCONS, PC.CDFILIAL, PC.CDPRODUTO,
                            PT.NMPRODUTO, PT.SGUNIDADE 
                   ORDER BY PT.CDARVPROD, 
                            PC.DTPREVCONS";
        
        $params = [
            "P_CDFILIAL"  => $filial,
            "P_DTINICIAL" => $params['DTINICIAL'],
            "P_DTFINAL"   => $params['DTFINAL'],
            "P_CDPRODINI" => $params['CDPRODINI'],
            "P_CDPRODFIN" => $params['CDPRODFIN'],
            "NRORG"       => $this->environment->getNrOrg()
        ];
        
        return self::executaSql($query, $params);
    }
    
    
    /**
     * Save file in FileServer
     */
    public function saveFileInFileServer($fileName)
    {
        try {
            if (file_exists($fileName)) {
                
                $file = file_get_contents($fileName);
                $extensao  = ".txt";
                $type      = 'text/plain'.$extensao;
                $finalFile = $type.';base64,'.base64_encode($file);
                
                $b64file = array(
                    "name" => $fileName,
                    /*"lastModified" =>  '',*/
                    "lastModifiedDate" => time(),
                    "webkitRelativePath" => '',
                    "type" => $type,
                    "size" => rand(1000, 20000),
                    "b64File" => $finalFile
                );
                
                $row['PREVCONS'] = array();
                $row['PREVCONS'][0] = $b64file;
                
                $this->fileUploader->uploadFilesInRow($row, 'PREVCONS', 'PREVCONS');
                
                unlink($fileName);
                
                return $row['PREVCONS'][0]['path'];
                
            }
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    private function getSolicita($nrNeceComp, $filiSoli)
    {
        $params = array(
    		"P_NRNECECMPSOL" => $nrNeceComp,
    		"P_CDFILSOLI"    => $filiSoli,
    		"P_CDFILLANCA"   => $this->environment->getCdFilial(),
    		"NRORG"          => $this->environment->getNrOrg()
    	);

    	$sql = "SELECT MAX(NRSOLICMP) NRSOLICMP 
    	          FROM SOLICITA 
    	         WHERE NRNECECMPSOL = :P_NRNECECMPSOL
    	           AND CDFILSOLI    = :P_CDFILSOLI
    	           AND CDFILLANCA   = :P_CDFILLANCA
    	           AND NRORG        = :NRORG";
    	           
    	$solicita = self::executaSql($sql, $params);
    	
    	return is_array($solicita) && count($solicita) ? $solicita[0]['NRSOLICMP'] : false;
    }
    
    public function saveFileName($row, $files) {
        $filter = $row['FILTER'];
        $container = $row['CONTAINER'];
        
        try {
            $this->beginTransaction();
            
            $sql = "INSERT INTO ANEXOSOLICITA (NRANEXOSOLICITA,
                                               NRNECECOMP,
                                           	   NRSOLICMP,
                                        	   CDFILSOLI,
                                        	   CDFILLANC,
                                               CDTELA,
                                               TIPOANEXO,
                                               DTANEXO, 
                                               NMANEXO,
                                               NMPATHANEXO)
                                       VALUES (:NRANEXOSOLICITA,
                                               :NRNECECOMP,
                                           	   :NRSOLICMP,
                                        	   :CDFILSOLI,
                                        	   :CDFILLANC,
                                               :CDTELA,
                                               :TIPOANEXO,
                                               :DTANEXO, 
                                               :NMANEXO,
                                               :NMPATHANEXO)";
            
            foreach($files as $file) {
                
                $solicita = self::getSolicita($filter['NECECOMP'], $file['CDFILIAL']);
                
                $params = array(
                    'NRANEXOSOLICITA'   => $this->newCode->getCodeByTableName('ANEXOSOLICITA', $this->environment->getNrOrg()),
                    'NRNECECOMP'        => $filter['NECECOMP'],
                    'NRSOLICMP'         => $solicita,
                    'CDFILSOLI'         => $file['CDFILIAL'],
                    'CDFILLANC'         => $this->environment->getCdFilial(),
                    'CDTELA'            => $container,
                    'TIPOANEXO'         => 'C',
                    'DTANEXO'           => DateTime::createFromFormat("d/m/Y", date("d/m/Y"))->format("d/m/Y"),
                    'NMANEXO'           => $file['FILENAME'],
                    'NMPATHANEXO'       => $file['FULLFILENAME']
                );
                
                self::executaSql($sql, $params, false);
            }
            
            $this->commit();
            
        } catch (\Exception $e) {
            $this->rollBack();
            throw $e;
        }
    }
    
    public function getCdSegMercFilial($cdFilial) {
        $sql = "SELECT
                   F.CDFILIAL, F.CDSEGMER
                FROM
                   FILIAL F
                WHERE
                   F.CDFILIAL = :P_CDFILIAL";
                   
        $params = array("P_CDFILIAL" => $cdFilial);           
                   
        $query = $this->connection->prepare($sql);
        $query->execute($params);
        
        $resultado = $query->fetchAll();
        
        if(isset($resultado[0])) {
            return $resultado[0]["CDSEGMER"];
        } else {
            return null;  
        }
    }
    
    public function verificaSegMercado($row, $filial) {
        $param = array();
        $param["P_CDFILIAL"]  = $filial;
        $param["P_CDPRODUTO"] = isset($row["NEW_CDPRODUTO"]) ? $row["NEW_CDPRODUTO"] : $row["CDPRODUTO"];
        
        $query = "SELECT FILIAL.CDFILIAL FROM FILIAL WHERE FILIAL.CDFILIAL = :P_CDFILIAL AND ((FILIAL.CDSEGMER IS NULL) 
         OR (EXISTS (SELECT 1 FROM PRODUTOSEG WHERE PRODUTOSEG.CDPRODUTO   = :P_CDPRODUTO AND NVL(PRODUTOSEG.IDPROSEGATIV, 'S') = 'S' AND PRODUTOSEG.CDSEGMER = FILIAL.CDSEGMER)))";
                       
        try {
            $std = $this->connection->prepare($query);
            $std->execute($param);
            
            $resultado = $std->fetchAll();
            
            return $resultado;
        } catch(Exception $e) {
            throw $e;
        }
    }
    
    public function verificaProdFiliAtivo($row, $filial) {
        $param = array();
        $param["P_CDFILIAL"]  = $filial;
        $param["P_CDPRODUTO"] = isset($row["NEW_CDPRODUTO"]) ? $row["NEW_CDPRODUTO"] : $row["CDPRODUTO"];
        
        $query = "SELECT PRODFILI.CDFILIAL FROM PRODFILI WHERE PRODFILI.CDFILIAL = :P_CDFILIAL AND PRODFILI.CDPRODUTO = :P_CDPRODUTO AND NVL(PRODFILI.IDPRODATIV, 'A') = 'A'";
                       
        try {
            $std = $this->connection->prepare($query);
            $std->execute($param);
            
            $resultado = $std->fetchAll();
            
            return $resultado;
        } catch(Exception $e) {
            throw $e;
        }
    }
}