/******************************************************************************/
/* Sistemas Integrados TECNISA                                                */
/* Nome: 0011_DENSTPO_USR_IMPORTAAF_DENADAI.sql                               */
/*                                                                            */
/* Descrio:                                                                 */
/* Procedure destinada a gerar uma AF no sistema da Teknisa correspondente    */
/* a cada nota fiscal de sada do operador logstico para as filiais, emitida */
/* atravs do sistema da Microsiga.                                           */
/* Criao:                                                                   */
/* 24/07/2008 - Raquel Cunha                                                  */
/******************************************************************************/

CREATE OR REPLACE
PROCEDURE USR_IMPORTAAF_DENADAI_OFICIAL IS
   ARQUIVO         UTL_FILE.FILE_TYPE;
   CAMINHO         VARCHAR(100);
   V_CDPRODUTO     VARCHAR(10);
   V_CDMARCA       VARCHAR(5);
   V_CODIGO        VARCHAR2(20);
   V_FILIAL        VARCHAR(4);
   V_FILLANC       VARCHAR(4);
   V_NRAUTOFORN    VARCHAR(10);
   V_OPERADOR      VARCHAR(12);
   V_EMITENTE      VARCHAR2(4);
   V_CDEMPRESA     VARCHAR(2);
   V_IDTIPEMITGER  VARCHAR(1);
   V_INSCESTA      VARCHAR(16);
   V_DTPROGENTAF   DATE;
   V_FORNECED      VARCHAR(21);
   V_CHAVE         VARCHAR2(20);

   V_FILIALA       VARCHAR(4);
   V_FILLANCA      VARCHAR(4);
   V_CODIGOA       VARCHAR2(20);

   V_CDFILDESTA    VARCHAR2(04);
   V_CDFILLANCA    VARCHAR2(04);
   V_NRAUTOFORNA   VARCHAR2(10);
   V_IDBAIXAAFA    VARCHAR2(01);
   V_VRTOTALAF     FLOAT;
   V_VRTOTENCARGO  FLOAT;
   V_PARCMPSUP     VARCHAR2(01);
   V_VERIFICA      VARCHAR2(21);
   V_CRIARQUIVO    BOOLEAN := TRUE;
BEGIN
   V_CHAVE := ' ';
   BEGIN
      SELECT DSDIRETORIO
        INTO CAMINHO
        FROM DIRETORIOS
       WHERE CDPROGRAMA = 'DEN00100';
   EXCEPTION
      WHEN NO_DATA_FOUND THEN
         CAMINHO := NULL;
   END;

   FOR C_AFIMPORT IN
      (SELECT ZW9.W9_EMPRESA, ZW9.W9_FILIAL, ZW9.W9_COD, ZW9.W9_DOC, ZW9.W9_CGC, SUBSTR(ZW9.W9_LOCAL,1,4) AS W9_CC,
              ZW9.W9_QUANT, ZW9.W9_PRCVEN, ZW9.W9_TOTAL, ZW9.W9_DESCON, ZW9.W9_SERIE, W9_DTENTR, W9_TPEDI,
              ZW9.W9_DTGRV, ZW9.W9_HRGRV, ZW9.W9_DTIMP, ZW9.W9_HRIMP,
              ZW9.ROWID
         FROM USR_ZW9 ZW9,
              (SELECT DISTINCT(CDFILIAL)
                 FROM FILGRUPFILI
                WHERE USR_IDPROTHEUS = 'S') FI
        WHERE ZW9.W9_DTIMP IS NULL
          AND ZW9.W9_HRIMP IS NULL
          AND FI.CDFILIAL = SUBSTR(ZW9.W9_LOCAL,1,4)
        ORDER BY ZW9.W9_FILIAL, ZW9.W9_DOC
       )
   LOOP
      IF C_AFIMPORT.W9_TPEDI = '1' THEN
         SELECT MAX(NVL(FILIAL.CDFILCENTCMP, FILIAL.CDFILIAL))
           INTO V_FILLANC
           FROM FILIAL, FILGRUPFILI
          WHERE FILGRUPFILI.USR_IDPROTHEUS = 'S'
            AND FILGRUPFILI.CDFILIAL = C_AFIMPORT.W9_CC
            AND FILIAL.CDFILIAL = FILGRUPFILI.CDFILIAL;

         IF NOT V_FILLANC IS NULL THEN
         
            V_FILIAL := C_AFIMPORT.W9_CC;

            V_PARCMPSUP := NULL;

            SELECT MAX(IDTIPEMITGER)
              INTO V_PARCMPSUP
              FROM PARCMPSUP
             WHERE CDFILIAL = V_FILIAL;
             
            IF NOT V_PARCMPSUP IS NULL THEN
               V_CDPRODUTO := NULL;

               SELECT MAX(CDPRODUTO)
                 INTO V_CDPRODUTO
                 FROM PRODUTO
                WHERE CDARVPROD = SUBSTR(C_AFIMPORT.W9_COD,1,10)
                  AND IDPRODATIVPR = 'S';
                 
               IF NOT V_CDPRODUTO IS NULL THEN
                  
                  SELECT MAX(CDMARCA)
                    INTO V_CDMARCA
                    FROM PARASUPRI
                   WHERE CDFILIAL = V_FILLANC;

                  IF NOT V_CDMARCA IS NULL THEN

                     V_OPERADOR := '999999999999';

                     SELECT MAX(CDFORNOPELOG)
                       INTO V_FORNECED
                       FROM FILIAL
                      WHERE CDFILIAL = V_FILIAL;

                     IF V_FORNECED IS NULL THEN
                        SELECT MAX(CDFORNECED)
                          INTO V_FORNECED
                          FROM FORNECEDOR
                         WHERE SUBSTR(NRINSJURFORN, 1, 14) =  C_AFIMPORT.W9_CGC;
                        IF V_FORNECED IS NULL THEN
                           SELECT MAX(CDFORNECED)
                             INTO V_FORNECED
                             FROM PRODFORNCOMP
                            WHERE PRODFORNCOMP.CDPRODCOMPL = V_CDPRODUTO;
                        END IF;
                     END IF;

                     IF NOT V_FORNECED IS NULL THEN

                        V_EMITENTE  := SUBSTR(EMITENTE(V_FILIAL, V_CDPRODUTO, V_FORNECED),1,4);
                        V_CDEMPRESA := SUBSTR(V_EMITENTE, 3, 2);

                        SELECT MAX(CDEMPRESA)
                          INTO V_VERIFICA
                          FROM EMPRESA
                         WHERE CDEMPRESA = V_CDEMPRESA;

                        IF NOT V_VERIFICA IS NULL THEN

                           V_IDTIPEMITGER := SUBSTR(V_EMITENTE, 1, 1);

                           IF V_IDTIPEMITGER IN ('1','2','3') THEN

                              IF C_AFIMPORT.W9_DTENTR IS NOT NULL THEN

                                 IF V_CHAVE <> C_AFIMPORT.W9_FILIAL||C_AFIMPORT.W9_DOC||C_AFIMPORT.W9_SERIE THEN
                                    V_VRTOTALAF    := 0;
                                    V_VRTOTENCARGO := 0;

                                    /* Calcula valor total da AF */
                                    SELECT SUM(VRPRODUTO) - NVL(SUM(VRDESCONTO), 0) + NVL(SUM(VRIMPOSTO), 0) AS VRTOTALAF
                                      INTO V_VRTOTALAF
                                      FROM (SELECT SUM(ITEMAUTF.QTPROGENTAF * ITEMAUTF.VRPREUNIAF) AS VRPRODUTO,
                                                   SUM((ITEMAUTF.QTPROGENTAF * ITEMAUTF.VRPREUNIAF * ITEMAUTF.VRPERDESAF) / 100) AS VRDESCONTO,
                                                   SUM(0) AS VRIMPOSTO
                                              FROM ITEMAUTF
                                             WHERE ITEMAUTF.CDFILDEST = V_FILIALA
                                               AND ITEMAUTF.CDFILLANC = V_FILLANCA
                                               AND ITEMAUTF.NRAUTOFORN = V_CODIGOA
                                             UNION
                                            SELECT SUM(0) AS VRPRODUTO,
                                                   SUM(0) AS VRDESCONTO,
                                                   SUM(IMPITMAF.VRADIMPAF) AS VRIMPOSTO
                                              FROM IMPITMAF, ITEMAUTF
                                              WHERE IMPITMAF.CDFILDEST = V_FILIALA
                                                AND IMPITMAF.CDFILLANC = V_FILLANCA
                                                AND IMPITMAF.NRAUTOFORN = V_CODIGOA
                                                AND IMPITMAF.CDFILDEST = ITEMAUTF.CDFILDEST
                                                AND IMPITMAF.CDFILLANC = ITEMAUTF.CDFILLANC
                                                AND IMPITMAF.NRAUTOFORN = ITEMAUTF.NRAUTOFORN
                                                AND IMPITMAF.CDPRODUTO = ITEMAUTF.CDPRODUTO
                                                AND IMPITMAF.CDMARCA = ITEMAUTF.CDMARCA
                                                AND IMPITMAF.DTPROGENTAF = ITEMAUTF.DTPROGENTAF);

                                    /* RETORNA O VALOR TOTAL DO ENCARGO DA AF  */
                                    SELECT NVL((SOMA.SUMVR - SUBTRAI.SUBTVR),0) VRTOTENCARGO
                                      INTO V_VRTOTENCARGO
                                      FROM (SELECT NVL(SUM(ENCARGOAF.VRENCARGOAF), 0) AS SUMVR
                                              FROM ENCARGOAF, ENCARGO
                                             WHERE (ENCARGO.IDENCARGO = 'A')
                                               AND (ENCARGO.CDENCARGO = ENCARGOAF.CDENCARGO)
                                               AND (ENCARGOAF.CDFILDEST = V_FILIALA)
                                               AND (ENCARGOAF.CDFILLANC = V_FILLANCA)
                                               AND (ENCARGOAF.NRAUTOFORN = V_CODIGOA)) SOMA,
                                           (SELECT NVL(SUM(ENCARGOAF.VRENCARGOAF), 0) AS SUBTVR
                                              FROM ENCARGOAF, ENCARGO
                                             WHERE (ENCARGO.IDENCARGO = 'D')
                                               AND (ENCARGO.CDENCARGO = ENCARGOAF.CDENCARGO)
                                               AND (ENCARGOAF.CDFILDEST = V_FILIALA)
                                               AND (ENCARGOAF.CDFILLANC = V_FILLANCA)
                                               AND (ENCARGOAF.NRAUTOFORN = V_CODIGOA)) SUBTRAI;

                                    UPDATE AUTOFORNE
                                       SET VRTOTALAF = (V_VRTOTALAF + V_VRTOTENCARGO)
                                     WHERE CDFILDEST = V_FILIALA
                                       AND CDFILLANC = V_FILLANCA
                                       AND NRAUTOFORN = V_CODIGOA;

                                    NOVO_CODIGO('AUTOFORNE', V_CODIGO, 1);
                                    V_CODIGO := SUBSTR(V_CODIGO, 11, 10);
                                    INSERT INTO AUTOFORNE
                                       (CDFILDEST, CDFILLANC, NRAUTOFORN, CDOPERADOR,
                                        CDFORNECED, DTAUTOFORN, IDTIPOEMITAF, CDEMPRESA, IDBAIXAAF, USR_IDEXPORTA, USR_W9_CGC, USR_W9_SERIE, USR_W9_DOC)
                                    VALUES
                                       (V_FILIAL, V_FILLANC, V_CODIGO, V_OPERADOR,
                                        V_FORNECED, TRUNC(SYSDATE), V_IDTIPEMITGER, V_CDEMPRESA, '1', 'N', C_AFIMPORT.W9_CGC, C_AFIMPORT.W9_SERIE, C_AFIMPORT.W9_DOC);

                                    V_CHAVE    := C_AFIMPORT.W9_FILIAL||C_AFIMPORT.W9_DOC||C_AFIMPORT.W9_SERIE;
                                    V_FILIALA  := V_FILIAL;
                                    V_FILLANCA := V_FILLANC;
                                    V_CODIGOA  := V_CODIGO;
                                 END IF;

                                 INSERT INTO ITEMAUTF
                                    (CDFILDEST, CDFILLANC, NRAUTOFORN,
                                     CDMARCA, CDPRODUTO,  DTPROGENTAF,
                                     VRPREUNIAF, QTPROGENTAF, NRPARCITMAF, IDBAIXITMAF)
                                 VALUES
                                    (V_FILIAL, V_FILLANC, V_CODIGO,
                                     V_CDMARCA, V_CDPRODUTO, C_AFIMPORT.W9_DTENTR,
                                     C_AFIMPORT.W9_PRCVEN, C_AFIMPORT.W9_QUANT, '00', '1');

                                 SELECT DTPROGENTAF,
                                        NVL(CDINCESTA_FILIAL, CDINSCESTA_EMPRCNT) AS CDINSCESTA
                                   INTO V_DTPROGENTAF,
                                        V_INSCESTA
                                   FROM (SELECT MIN(CDINSCESTA) AS CDINSCESTA_EMPRCNT
                                           FROM EMPRCNTRFIL
                                          WHERE CDEMPRESA = V_CDEMPRESA),
                                        (SELECT MIN(DTPROGENTAF) AS DTPROGENTAF
                                           FROM ITEMAUTF
                                          WHERE CDFILDEST  = V_FILIAL
                                            AND CDFILLANC  = V_FILLANC
                                            AND NRAUTOFORN = V_CODIGO),
                                        (SELECT MIN(CDINSCESTA) AS CDINCESTA_FILIAL
                                           FROM FILIAL
                                          WHERE CDFILIAL  = V_FILIAL
                                            AND CDEMPRESA = V_CDEMPRESA);

                                 UPDATE USR_ZW9
                                    SET W9_DTIMP = TO_DATE(TRUNC(SYSDATE)),
                                        W9_HRIMP = TO_CHAR(SYSDATE, 'HH24MI')
                                  WHERE W9_FILIAL = C_AFIMPORT.W9_FILIAL
                                    AND W9_DOC = C_AFIMPORT.W9_DOC
                                    AND W9_SERIE = C_AFIMPORT.W9_SERIE;

                                 IMPOSTO_ITEMAF(V_CDEMPRESA, V_INSCESTA, V_FORNECED,
                                                V_FILIAL, V_FILLANC, V_CODIGO, V_DTPROGENTAF);
                              ELSE
                                 IF (CAMINHO IS NOT NULL) THEN
                                    IF V_CRIARQUIVO THEN
                                       ARQUIVO := UTL_FILE.FOPEN(CAMINHO, 'LOGTEK_' || TO_CHAR(SYSDATE, 'DDMMYYYY_HHMISS') || '.TXT', 'A');
                                       UTL_FILE.PUT_LINE(ARQUIVO, 'Inconsistencias geradas na importacao de nota fiscal Protheus:');
                                       V_CRIARQUIVO := FALSE;
                                    END IF;
                                    UTL_FILE.PUT_LINE(ARQUIVO, 'Data programada de entrega da AF deve ser informada - Documento ' || C_AFIMPORT.W9_DOC);
                                 END IF;
                              END IF;
                           ELSE
                              IF (CAMINHO IS NOT NULL) THEN
                                 IF V_CRIARQUIVO THEN
                                    ARQUIVO := UTL_FILE.FOPEN(CAMINHO, 'LOGTEK_' || TO_CHAR(SYSDATE, 'DDMMYYYY_HHMISS') || '.TXT', 'A');
                                    UTL_FILE.PUT_LINE(ARQUIVO, 'Inconsistencias geradas na importacao de nota fiscal Protheus:');
                                    V_CRIARQUIVO := FALSE;
                                 END IF;
                                 UTL_FILE.PUT_LINE(ARQUIVO, 'Identificador do tipo de emitente ' || V_IDTIPEMITGER || ' invalido - Documento ' || C_AFIMPORT.W9_DOC);
                              END IF;
                           END IF;
                        ELSE
                           IF (CAMINHO IS NOT NULL) THEN
                              IF V_CRIARQUIVO THEN
                                 ARQUIVO := UTL_FILE.FOPEN(CAMINHO, 'LOGTEK_' || TO_CHAR(SYSDATE, 'DDMMYYYY_HHMISS') || '.TXT', 'A');
                                 UTL_FILE.PUT_LINE(ARQUIVO, 'Inconsistencias geradas na importacao de nota fiscal Protheus:');
                                 V_CRIARQUIVO := FALSE;
                              END IF;
                              UTL_FILE.PUT_LINE(ARQUIVO, 'Empresa ' || SUBSTR(V_EMITENTE, 3, 2) || ' nao cadastrada - Documento ' || C_AFIMPORT.W9_DOC);
                           END IF;
                        END IF;
                     ELSE
                        IF (CAMINHO IS NOT NULL) THEN
                           IF V_CRIARQUIVO THEN
                              ARQUIVO := UTL_FILE.FOPEN(CAMINHO, 'LOGTEK_' || TO_CHAR(SYSDATE, 'DDMMYYYY_HHMISS') || '.TXT', 'A');
                              UTL_FILE.PUT_LINE(ARQUIVO, 'Inconsistencias geradas na importacao de nota fiscal Protheus:');
                              V_CRIARQUIVO := FALSE;
                           END IF;
                           UTL_FILE.PUT_LINE(ARQUIVO, 'Fornecedor (Inscricao Juridica) ' || C_AFIMPORT.W9_CGC || ' nao cadastrado - Documento ' || C_AFIMPORT.W9_DOC);
                        END IF;
                     END IF;
                  ELSE
                     IF (CAMINHO IS NOT NULL) THEN
                        IF V_CRIARQUIVO THEN
                           ARQUIVO := UTL_FILE.FOPEN(CAMINHO, 'LOGTEK_' || TO_CHAR(SYSDATE, 'DDMMYYYY_HHMISS') || '.TXT', 'A');
                           UTL_FILE.PUT_LINE(ARQUIVO, 'Inconsistencias geradas na importacao de nota fiscal Protheus:');
                           V_CRIARQUIVO := FALSE;
                        END IF;
                        UTL_FILE.PUT_LINE(ARQUIVO, 'No ha Marca parametrizada para a Filial ' || V_FILLANC || ' - Documento ' || C_AFIMPORT.W9_DOC);
                     END IF;
                  END IF;
               ELSE
                  IF (CAMINHO IS NOT NULL) THEN
                     IF V_CRIARQUIVO THEN
                        ARQUIVO := UTL_FILE.FOPEN(CAMINHO, 'LOGTEK_' || TO_CHAR(SYSDATE, 'DDMMYYYY_HHMISS') || '.TXT', 'A');
                        UTL_FILE.PUT_LINE(ARQUIVO, 'Inconsistencias geradas na importacao de nota fiscal Protheus:');
                        V_CRIARQUIVO := FALSE;
                     END IF;
                     UTL_FILE.PUT_LINE(ARQUIVO, 'Produto ' || SUBSTR(C_AFIMPORT.W9_COD,1,10) || ' nao cadastrado ou inativo - Documento ' || C_AFIMPORT.W9_DOC);
                  END IF;
               END IF;
            ELSE
               IF (CAMINHO IS NOT NULL) THEN
                  IF V_CRIARQUIVO THEN
                     ARQUIVO := UTL_FILE.FOPEN(CAMINHO, 'LOGTEK_' || TO_CHAR(SYSDATE, 'DDMMYYYY_HHMISS') || '.TXT', 'A');
                     UTL_FILE.PUT_LINE(ARQUIVO, 'Inconsistencias geradas na importacao de nota fiscal Protheus:');
                     V_CRIARQUIVO := FALSE;
                  END IF;
                  UTL_FILE.PUT_LINE(ARQUIVO, 'Filial ' || V_FILIAL || ', nao existe parametrizacao de emitente (Suprimentos) - Documento ' || C_AFIMPORT.W9_DOC);
               END IF;
            END IF;
         ELSE
            IF (CAMINHO IS NOT NULL) THEN
               IF V_CRIARQUIVO THEN
                  ARQUIVO := UTL_FILE.FOPEN(CAMINHO, 'LOGTEK_' || TO_CHAR(SYSDATE, 'DDMMYYYY_HHMISS') || '.TXT', 'A');
                  UTL_FILE.PUT_LINE(ARQUIVO, 'Inconsistencias geradas na importacao de nota fiscal Protheus:');
                  V_CRIARQUIVO := FALSE;
               END IF;
               UTL_FILE.PUT_LINE(ARQUIVO, 'Filial ' || C_AFIMPORT.W9_CC || ' nao parametrizada para importacao Protheus - Documento ' || C_AFIMPORT.W9_DOC);
            END IF;
         END IF;
      ELSE
         IF C_AFIMPORT.W9_TPEDI = '2' THEN
            SELECT MAX(CDFILDEST), MAX(CDFILLANC), MAX(NRAUTOFORN), NVL(MAX(IDBAIXAAF),'1')
              INTO V_CDFILDESTA, V_CDFILLANCA, V_NRAUTOFORNA, V_IDBAIXAAFA
              FROM AUTOFORNE
             WHERE USR_W9_CGC = C_AFIMPORT.W9_CGC
               AND USR_W9_SERIE = C_AFIMPORT.W9_SERIE
               AND USR_W9_DOC = C_AFIMPORT.W9_DOC;

            IF V_IDBAIXAAFA = '1' THEN
               UPDATE AUTOFORNE
               SET IDBAIXAAF = '5'
               WHERE CDFILDEST = V_CDFILDESTA
                 AND CDFILLANC = V_CDFILLANCA
                 AND NRAUTOFORN = V_NRAUTOFORNA;
            END IF;

            UPDATE USR_ZW9
               SET W9_DTIMP = TO_DATE(TRUNC(SYSDATE)),
                   W9_HRIMP = TO_CHAR(SYSDATE, 'HH24MI')
             WHERE W9_FILIAL = C_AFIMPORT.W9_FILIAL
               AND W9_DOC = C_AFIMPORT.W9_DOC
               AND W9_SERIE = C_AFIMPORT.W9_SERIE
               AND W9_COD = C_AFIMPORT.W9_COD;
         END IF;
      END IF;
   END LOOP;

   V_VRTOTALAF    := 0;
   V_VRTOTENCARGO := 0;

   /* Calcula valor total da AF */
   SELECT SUM(VRPRODUTO) - NVL(SUM(VRDESCONTO), 0) + NVL(SUM(VRIMPOSTO), 0) AS VRTOTALAF
     INTO V_VRTOTALAF
     FROM (SELECT SUM(ITEMAUTF.QTPROGENTAF * ITEMAUTF.VRPREUNIAF) AS VRPRODUTO,
                  SUM((ITEMAUTF.QTPROGENTAF * ITEMAUTF.VRPREUNIAF * ITEMAUTF.VRPERDESAF) / 100) AS VRDESCONTO,
                  SUM(0) AS VRIMPOSTO
             FROM ITEMAUTF
            WHERE ITEMAUTF.CDFILDEST = V_FILIAL
              AND ITEMAUTF.CDFILLANC = V_FILLANC
              AND ITEMAUTF.NRAUTOFORN = V_CODIGO
            UNION
           SELECT SUM(0) AS VRPRODUTO,
                  SUM(0) AS VRDESCONTO,
                  SUM(IMPITMAF.VRADIMPAF) AS VRIMPOSTO
             FROM IMPITMAF, ITEMAUTF
             WHERE IMPITMAF.CDFILDEST = V_FILIAL
               AND IMPITMAF.CDFILLANC = V_FILLANC
               AND IMPITMAF.NRAUTOFORN = V_CODIGO
               AND IMPITMAF.CDFILDEST = ITEMAUTF.CDFILDEST
               AND IMPITMAF.CDFILLANC = ITEMAUTF.CDFILLANC
               AND IMPITMAF.NRAUTOFORN = ITEMAUTF.NRAUTOFORN
               AND IMPITMAF.CDPRODUTO = ITEMAUTF.CDPRODUTO
               AND IMPITMAF.CDMARCA = ITEMAUTF.CDMARCA
               AND IMPITMAF.DTPROGENTAF = ITEMAUTF.DTPROGENTAF);

   /* RETORNA O VALOR TOTAL DO ENCARGO DA AF  */
   SELECT NVL((SOMA.SUMVR - SUBTRAI.SUBTVR),0) VRTOTENCARGO
     INTO V_VRTOTENCARGO
     FROM (SELECT NVL(SUM(ENCARGOAF.VRENCARGOAF), 0) AS SUMVR
             FROM ENCARGOAF, ENCARGO
            WHERE (ENCARGO.IDENCARGO = 'A')
              AND (ENCARGO.CDENCARGO = ENCARGOAF.CDENCARGO)
              AND (ENCARGOAF.CDFILDEST = V_FILIAL)
              AND (ENCARGOAF.CDFILLANC = V_FILLANC)
              AND (ENCARGOAF.NRAUTOFORN = V_CODIGO)) SOMA,
          (SELECT NVL(SUM(ENCARGOAF.VRENCARGOAF), 0) AS SUBTVR
             FROM ENCARGOAF, ENCARGO
            WHERE (ENCARGO.IDENCARGO = 'D')
              AND (ENCARGO.CDENCARGO = ENCARGOAF.CDENCARGO)
              AND (ENCARGOAF.CDFILDEST = V_FILIAL)
              AND (ENCARGOAF.CDFILLANC = V_FILLANC)
              AND (ENCARGOAF.NRAUTOFORN = V_CODIGO)) SUBTRAI;

   UPDATE AUTOFORNE
      SET VRTOTALAF = (V_VRTOTALAF + V_VRTOTENCARGO)
    WHERE CDFILDEST = V_FILIAL
      AND CDFILLANC = V_FILLANC
      AND NRAUTOFORN = V_CODIGO;
   IF NOT V_CRIARQUIVO THEN
      UTL_FILE.FCLOSE(ARQUIVO);
   END IF;

   COMMIT;
END;
/

-- VERSAO --
BEGIN ATUVEROBJ('USR_IMPORTAAF_DENADAI_OFICIAL','5.50.XXX'); END;
/

