/* Sistemas Integrados TEKNISA

Nome: 400G_ESTTRGO_ATUALIZA_INSERT_LOTE.SQL

Descrio:
Trigger para inserir ordenao do Lote.

Criao
14/07/2006 - Fabrcio Marcelo
*/

IF EXISTS(SELECT * FROM sysobjects O, sysusers U
          WHERE
            o.name = 'ATUALIZA_INSERT_LOTE'  and
            type = 'TR'               and
            u.uid = o.uid             and
            u.name = USER)
DROP TRIGGER ATUALIZA_INSERT_LOTE
GO

CREATE TRIGGER ATUALIZA_INSERT_LOTE
ON LOTE
FOR INSERT, UPDATE
AS
   DECLARE @V_CDPRODEXT   VARCHAR(20);   /* Codigo do produto externo */
   DECLARE @V_STORDELOTE  VARCHAR(50);   /* Ordenao do Lote */
   DECLARE @V_STNUMELOTE  VARCHAR(50);   /* Numero do Lote */
   DECLARE @V_SEQLOTE     VARCHAR(20);   /* Sequencial do Lote */
   DECLARE @V_INAJUSTA    INT;           /* Valor do complemento da variavel seq */

   DECLARE @V_NEW_CDFILIAL    VARCHAR(4);
   DECLARE @V_NEW_CDPRODUTO   VARCHAR(10);
   DECLARE @V_NEW_NRLOTEESTQ  VARCHAR(20);
   DECLARE @V_NEW_NRSUBLOTE   VARCHAR(20);
   DECLARE @V_NEW_DTENTRLOTE  DATETIME;

   DECLARE @V_OLD_CDFILIAL    VARCHAR(4);
   DECLARE @V_OLD_CDPRODUTO   VARCHAR(10);
   DECLARE @V_OLD_NRLOTEESTQ  VARCHAR(20);
   DECLARE @V_OLD_NRSUBLOTE   VARCHAR(20);
   DECLARE @V_OLD_DTENTRLOTE  DATETIME;
   DECLARE @V_DATA            DATETIME;
   DECLARE @V_STATUS          VARCHAR;


BEGIN
   DECLARE C_LOTEPR CURSOR FOR
      SELECT
         'I' STATUS,
         INSERTED.CDFILIAL,
         INSERTED.CDPRODUTO,
         INSERTED.NRLOTEESTQ,
         INSERTED.NRSUBLOTE,
         INSERTED.DTENTRLOTE,
         NULL,
         NULL,
         NULL,
         NULL,
         NULL
      FROM
         INSERTED
      WHERE
         0 = (SELECT COUNT(*) FROM DELETED)

      UNION ALL

      SELECT
         'U' STATUS,
         NULL,
         NULL,
         NULL,
         NULL,
         NULL,
         DELETED.CDFILIAL,
         DELETED.CDPRODUTO,
         DELETED.NRLOTEESTQ,
         DELETED.NRSUBLOTE,
         DELETED.DTENTRLOTE
      FROM
         INSERTED, DELETED
      WHERE
         INSERTED.CDFILIAL    = DELETED.CDFILIAL     AND
         INSERTED.CDPRODUTO   = DELETED.CDPRODUTO    AND
         INSERTED.NRLOTEESTQ  = DELETED.NRLOTEESTQ   AND
         INSERTED.NRSUBLOTE   = DELETED.NRSUBLOTE;

   OPEN C_LOTEPR;

   FETCH NEXT FROM C_LOTEPR INTO @V_STATUS,
                                     @V_NEW_CDFILIAL,   @V_NEW_CDPRODUTO,
                                     @V_NEW_NRLOTEESTQ, @V_NEW_NRSUBLOTE,
                                     @V_NEW_DTENTRLOTE, @V_OLD_CDFILIAL,
                                     @V_OLD_CDPRODUTO,  @V_OLD_NRLOTEESTQ,
                                     @V_OLD_NRSUBLOTE,  @V_OLD_DTENTRLOTE;

   WHILE (@@FETCH_STATUS = 0) BEGIN

      SET @V_STORDELOTE =  '';

      SET @V_DATA = ISNULL(@V_NEW_DTENTRLOTE,GETDATE());

      SELECT
         @V_CDPRODEXT = MAX(ISNULL(CDPRODINTE, ''))
      FROM
         PRODUTO
      WHERE
         (CDPRODUTO = @V_NEW_CDPRODUTO);

      SELECT
         @V_STORDELOTE = MAX(ISNULL(DSORDENALOTE,'')),
         @V_STNUMELOTE = MAX(ISNULL(DSNUMELOTE,''))
      FROM
         PARAMFILIAL
      WHERE
         CDFILIAL = @V_NEW_CDFILIAL;

      SET @V_STNUMELOTE = REPLACE(@V_STNUMELOTE, '[ANO]'  , RIGHT(CONVERT(VARCHAR, YEAR(@V_DATA)), 4));
      SET @V_STNUMELOTE = REPLACE(@V_STNUMELOTE, '[ANO2]' , RIGHT(CONVERT(VARCHAR, YEAR(@V_DATA)), 2));
      SET @V_STNUMELOTE = REPLACE(@V_STNUMELOTE, '[ANO4]' , RIGHT(CONVERT(VARCHAR, YEAR(@V_DATA)), 4));

      SET @V_STNUMELOTE = REPLACE(@V_STNUMELOTE, '[MES]'  , RIGHT(CONVERT(VARCHAR, MONTH(@V_DATA)), 4));
      SET @V_STNUMELOTE = REPLACE(@V_STNUMELOTE, '[DIA]'  , RIGHT(CONVERT(VARCHAR, DAY(@V_DATA)), 4));
      SET @V_STNUMELOTE = REPLACE(@V_STNUMELOTE, '[FIL]'  , @V_NEW_CDFILIAL);
      SET @V_STNUMELOTE = REPLACE(@V_STNUMELOTE, '[CDEXT]', @V_CDPRODEXT);

      IF CHARINDEX('[SEQ]',@V_STNUMELOTE) > 0 BEGIN
         SET @V_SEQLOTE = SUBSTRING(@V_NEW_NRLOTEESTQ, CHARINDEX('[SEQ]',@V_STNUMELOTE), 10);
      END
      ELSE BEGIN
         IF CHARINDEX('[SEQ',@V_STNUMELOTE) > 0 BEGIN
            SET @V_INAJUSTA = CONVERT(INT, SUBSTRING(@V_STNUMELOTE, CHARINDEX('[SEQ',@V_STNUMELOTE) + 4, 1));
            SET @V_SEQLOTE  = SUBSTRING(@V_NEW_NRLOTEESTQ, CHARINDEX('[SEQ',@V_STNUMELOTE), @V_INAJUSTA);
         END;
      END;

      SET @V_STORDELOTE = REPLACE(@V_STORDELOTE, '[ANO]'  , RIGHT(CONVERT(VARCHAR, YEAR(@V_DATA)), 4));
      SET @V_STORDELOTE = REPLACE(@V_STORDELOTE, '[ANO2]' , RIGHT(CONVERT(VARCHAR, YEAR(@V_DATA)), 2));
      SET @V_STORDELOTE = REPLACE(@V_STORDELOTE, '[ANO4]' , RIGHT(CONVERT(VARCHAR, YEAR(@V_DATA)), 4));

      SET @V_STORDELOTE = REPLACE(@V_STORDELOTE, '[MES]'  , RIGHT(CONVERT(VARCHAR, MONTH(@V_DATA)), 4));
      SET @V_STORDELOTE = REPLACE(@V_STORDELOTE, '[DIA]'  , RIGHT(CONVERT(VARCHAR, DAY(@V_DATA)), 4));
      SET @V_STORDELOTE = REPLACE(@V_STORDELOTE, '[FIL]'  , @V_NEW_CDFILIAL);
      SET @V_STORDELOTE = REPLACE(@V_STORDELOTE, '[CDEXT]', @V_CDPRODEXT);

      IF CHARINDEX('[SEQ]',@V_STORDELOTE) > 0 BEGIN
         SET @V_STORDELOTE = REPLACE(@V_STORDELOTE, '[SEQ]'  , @V_SEQLOTE);
      END
      ELSE BEGIN
         IF CHARINDEX('[SEQ',@V_STORDELOTE) > 0 BEGIN
            SET @V_INAJUSTA   = CONVERT(INT, SUBSTRING(@V_STORDELOTE, CHARINDEX('[SEQ',@V_STORDELOTE) + 4, 1));
            SET @V_STORDELOTE = REPLACE(@V_STORDELOTE, '[SEQ'+CONVERT(VARCHAR, @V_INAJUSTA)+']', @V_SEQLOTE);
         END;
      END;

     IF NOT (@V_STORDELOTE IS NULL) BEGIN
         UPDATE LOTE
         SET CDORDENALOTE = @V_STORDELOTE
         FROM INSERTED
         WHERE
            (LOTE.CDFILIAL   = @V_OLD_CDFILIAL)   AND
            (LOTE.NRLOTEESTQ = @V_OLD_NRLOTEESTQ) AND
            (LOTE.NRSUBLOTE  = @V_OLD_NRSUBLOTE)  AND
            (LOTE.CDPRODUTO  = @V_OLD_CDPRODUTO);
      END;

      FETCH NEXT FROM C_LOTEPR INTO @V_STATUS,
                                    @V_NEW_CDFILIAL,   @V_NEW_CDPRODUTO,
                                    @V_NEW_NRLOTEESTQ, @V_NEW_NRSUBLOTE,
                                    @V_NEW_DTENTRLOTE, @V_OLD_CDFILIAL,
                                    @V_OLD_CDPRODUTO,  @V_OLD_NRLOTEESTQ,
                                    @V_OLD_NRSUBLOTE,  @V_OLD_DTENTRLOTE;
   END;
   CLOSE C_LOTEPR;
   DEALLOCATE C_LOTEPR;

END;
GO

-- VERSAO --
EXEC ATUVEROBJ 'ATUALIZA_INSERT_LOTE','5.01.017';
GO


